fn check_elided_return(
producer: AliveProducer,
signature: &SignatureInfo,
) -> SmtCheckResultExpand description
Checks whether an elided return lifetime can be tied to the receiver borrow.
fn check_elided_return(
producer: AliveProducer,
signature: &SignatureInfo,
) -> SmtCheckResultChecks whether an elided return lifetime can be tied to the receiver borrow.